@@ -253,7 +253,7 @@ def script_to_html(
     else:
         panel_req = f'panel=={panel_version}'
         bokeh_req = f'bokeh=={BOKEH_VERSION}'
-    base_reqs = [bokeh_req, panel_req]
+    base_reqs = ['markdown-it-py<3', bokeh_req, panel_req]
     if http_patch:
         base_reqs.append('pyodide-http==0.2.1')
     reqs = base_reqs + [
