@@ -3,6 +3,8 @@ Vanilla template
 """
 import pathlib
 
+from typing import ClassVar, Dict
+
 import param
 
 from ...theme import Design
@@ -21,4 +23,10 @@ class VanillaTemplate(BasicTemplate):
 
     _css = pathlib.Path(__file__).parent / 'vanilla.css'
 
+    _resources: ClassVar[Dict[str, Dict[str, str]]] = {
+        'css': {
+            'lato': "https://fonts.googleapis.com/css?family=Lato&subset=latin,latin-ext"
+        }
+    }
+
     _template = pathlib.Path(__file__).parent / 'vanilla.html'
